{
    "block" : "page",
    "mods" : [
    ],
    "content" : [
        {
            "block" : "heading"
        },
        {
            "MODULE": "Data::Context::BEM::Block::Story",
            "METHOD": "get_data",
            "block" : "heading"
        }
    ]
}
